pub enum AutoencoderType {
Vanilla,
Denoising,
Sparse,
}Expand description
Variant of self-supervised autoencoder reconstruction objective
Variants
Vanilla
Standard autoencoder minimizing reconstruction loss
Denoising
Autoencoder trained to reconstruct clean inputs from corrupted inputs
Sparse
Autoencoder with a sparsity penalty on the latent activations